<?php

namespace Drupal\bulk_alias_checker\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\file\Entity\File;
use Drupal\Component\Utility\UrlHelper;

/**
 * Implements a form.
 */
class AliascheckerForm extends FormBase {

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'bulk_alias_checker_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        $form['bulk_alias_checkerholder'] = array(
            '#type' => 'fieldset',
            '#description' => t('Upload a CSV file.'),
            '#collapsible' => TRUE,
            '#collapsed' => FALSE,
        );

        $form['bulk_alias_checkerholder']['file_upload'] = array(
            '#type' => 'managed_file',
            '#title' => t('CSV File'),
            '#size' => 40,
            '#upload_location' => 'public://bulk_alias_checkerholder/',
            '#description' => t('Select the CSV file to check whether Alias are exist or not.'),
            '#upload_validators' => array('file_validate_extensions' => array('csv')),
        );

        $form['bulk_alias_checkerholder']['sample_file'] = array(
            '#markup' => '<p>' . \Drupal::l(t('Click here to download sample file'), new Url('sample_bulk_alias_checker')) . '</p>',
        );

        $form['bulk_alias_checkerholder']['submit_button'] = array(
            '#type' => 'submit',
            '#value' => t('Submit'),
        );

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state) {
        // Attempt to save the uploaded file.
//  $validators = array('file_validate_extensions' => array('csv'));
//
//  $file = file_save_upload('file_upload', $validators);
//
//  if (!$file) {
//    form_set_error('file_upload', t('A file must be uploaded or selected.'));
//  }
//  elseif ($file->filemime != 'text/csv') {
//    form_set_error('file_upload', t('The file must be of CSV type only.'));
//  }
//  else {
//    // Set files to form_state, to process when form is submitted.
//    $form_state['values']['file_upload'] = $file;
//  }
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {

        $line_max = 2000;
        $formstate = $form_state->getValues();
        $fid = $formstate['file_upload'][0];
        $file = File::load($fid);
        $file->setPermanent();
        $file->save();
        $url = $file->getFileUri();
        $filepath = file_create_url($url);
        $handle = fopen($filepath, 'r');


        $send_counter = 0;
        $data = array();
        while ($row = fgetcsv($handle, $line_max, ',')) {
            if ($send_counter != 0) {
                $data[] = $row;
            }
            $send_counter++;
        }

//   $operations = array();
//
  foreach ($data as $csvdata) {
    $first_string = trim($csvdata[0]);
    if (!empty($first_string) && isset($first_string)) {
      $operations[] = array('bulk_alias_checker_op', array($csvdata));
    }
  }


        $batch = array(
            'title' => t('Checking the node alias finally....please wait....!'),
            'operations' => $operations,
            'init_message' => t('Node alias checking started...please wait....!'),
            'finished' => 'bulk_alias_checker_op_batch_finished',
            'file' => drupal_get_path('module', 'bulk_alias_checker') . '/includes/bulk_alias_checker.inc',
            'progress_message' => t('Processed @current out of @total.'),
            'error_message' => t('Node alias checking process has encountered an error.'),
        );

        batch_set($batch);
    }

}
